@@ -286,7 +286,7 @@ def _parse_artist(json_obj):
     for role in json_obj.get('artistTypes', [json_obj.get('type')]):
         roles.append(Role(role))
 
-    return Artist(id=json_obj['id'], name=json_obj['name'], roles=roles, role=roles[0])
+    return Artist(id=json_obj['id'], name=json_obj['name'], img_uuid=json_obj.get('picture'), roles=roles, role=roles[0])
 
 
 def _parse_artists(json_obj):
@@ -301,6 +301,7 @@ def _parse_album(json_obj, artist=None, artists=None):
     kwargs = {
         'id': json_obj['id'],
         'name': json_obj['title'],
+        'img_uuid': json_obj.get('cover'),
         'num_tracks': json_obj.get('numberOfTracks'),
         'num_discs': json_obj.get('numberOfVolumes'),
         'duration': json_obj.get('duration'),
@@ -328,6 +329,7 @@ def _parse_playlist(json_obj):
     kwargs = {
         'id': json_obj['uuid'],
         'name': json_obj['title'],
+        'img_uuid': json_obj.get('squareImage'),
         'description': json_obj['description'],
         'num_tracks': int(json_obj['numberOfTracks']),
         'duration': int(json_obj['duration']),
@@ -407,7 +409,15 @@ class Favorites(object):
         return self._session._map_request(self._base_url + '/albums', ret='albums')
 
     def playlists(self):
-        return self._session._map_request(self._base_url + '/playlists', ret='playlists')
+        favorites = self._session._map_request(self._base_url + '/playlists', ret='playlists')
+        created_playlists = self._session.get_user_playlists(self._session.user.id)
+
+        # Don't append duplicates to the return value
+        for playlist in created_playlists:
+            if not any(playlist.id == favorite.id for favorite in favorites):
+                favorites.append(playlist)
+
+        return favorites
 
     def tracks(self):
         request = self._session.request('GET', self._base_url + '/tracks')
